# gendotmatrix

**Gendotmatrix**: a tool to extract dot matrix font from vector font.

## Install:

```
pip install gendotmatrix
```

## Usage:

```
gendotmatrix.py --help
```

example:

    gendotmatrix.py -o ubuntu-c.font  -s "32x32" "/usr/share/fonts/truetype/ubuntu-font-family/Ubuntu-C.ttf"
